@@ -106,7 +106,7 @@ EditorView::EditorView(QWidget *parent, Catalog* catalog/*,keyEventHandler* kh*/
     m_sourceTextEdit->setWhatsThis(i18n("<qt><p><b>Original String</b></p>\n"
                                         "<p>This part of the window shows the original message\n"
                                         "of the currently displayed entry.</p></qt>"));
-    m_sourceTextEdit->viewport()->setBackgroundRole(QPalette::Background);
+    m_sourceTextEdit->viewport()->setBackgroundRole(QPalette::Window);
 
     m_sourceTextEdit->setVisualizeSeparators(Settings::self()->visualizeSeparators());
     m_targetTextEdit->setVisualizeSeparators(Settings::self()->visualizeSeparators());
@@ -131,6 +131,8 @@ EditorView::EditorView(QWidget *parent, Catalog* catalog/*,keyEventHandler* kh*/
     connect(m_targetTextEdit, &TranslationUnitTextEdit::findNextRequested, this, &EditorView::findNextRequested);
     connect(m_sourceTextEdit, &TranslationUnitTextEdit::replaceRequested, this, &EditorView::replaceRequested);
     connect(m_targetTextEdit, &TranslationUnitTextEdit::replaceRequested, this, &EditorView::replaceRequested);
+    connect(m_sourceTextEdit, &TranslationUnitTextEdit::zoomRequested, m_targetTextEdit, &TranslationUnitTextEdit::zoomRequestedSlot);
+    connect(m_targetTextEdit, &TranslationUnitTextEdit::zoomRequested, m_sourceTextEdit, &TranslationUnitTextEdit::zoomRequestedSlot);
 
     connect(this, &EditorView::doExplicitCompletion, m_targetTextEdit, &TranslationUnitTextEdit::doExplicitCompletion);
 
