@@ -130,7 +130,8 @@ void PoItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option
 
 // Temporary workaround for Qt bug https://bugreports.qt.io/browse/QTBUG-78094
 // to ensure that large numbers are formatted using a thousands separator
-QString PoItemDelegate::displayText(const QVariant & value, const QLocale & locale) const {
+QString PoItemDelegate::displayText(const QVariant & value, const QLocale & locale) const
+{
     return QStyledItemDelegate::displayText(value, QLocale::system());
 }
 
@@ -270,6 +271,7 @@ bool SortFilterProxyModel::lessThan(const QModelIndex& left,
     case ProjectModel::ProjectModelColumns::LastTranslator:
     case ProjectModel::ProjectModelColumns::SourceDate:
     case ProjectModel::ProjectModelColumns::TranslationDate:
+    case ProjectModel::ProjectModelColumns::Comment:
         return collator.compare(projectModel->data(left).toString(), projectModel->data(right).toString()) < 0;
     case ProjectModel::ProjectModelColumns::TotalCount:
     case ProjectModel::ProjectModelColumns::TranslatedCount:
@@ -300,8 +302,8 @@ ProjectWidget::ProjectWidget(/*Catalog* catalog, */QWidget* parent)
 
     setUniformRowHeights(true);
     setAllColumnsShowFocus(true);
-    int widthDefaults[] = {6, 1, 1, 1, 1, 1, 1, 4, 4, 4};
-    //FileName, Graph, TotalCount, TranslatedCount, FuzzyCount, UntranslatedCount, IncompleteCount, SourceDate, TranslationDate, LastTranslator
+    int widthDefaults[] = {6, 1, 1, 1, 1, 1, 1, 4, 4, 4, 4};
+    //FileName, Graph, TotalCount, TranslatedCount, FuzzyCount, UntranslatedCount, IncompleteCount, Comment, SourceDate, TranslationDate, LastTranslator
     int i = sizeof(widthDefaults) / sizeof(int);
     int baseWidth = columnWidth(0);
     while (--i >= 0)
